Authors
=======

Sangjoon Lee, Anton Oliynyk, Emil Jaffal, Danila Shiryaev

Contributors
------------

For a list of contributors, visit
https://github.com/bobleesj/structure-analyzer-featurizer/graphs/contributors
